#!/usr/bin/env python

import subprocess
import sys

req_version = (3, 5)
cur_version = sys.version_info

if cur_version < req_version:
    print("python version >=3.5 required")
    sys.exit(1)

# Alpine
images = ["swarm", "trigger", "common", "docs", "linux"]
for image in images:
    print("Building %s ..." % (image))
    proc_args = ["docker", "build", "-t", "alpine:%s" % (image), image]
    subprocess.run(proc_args).check_returncode()
    proc_args = ["docker", "tag", "alpine:%s" % (image),
                 "dev-docker.governikus.de/ausweisapp2/alpine:%s" % image]
    subprocess.run(proc_args).check_returncode()



#!/usr/bin/env python

import sys

if sys.version_info < (3, 1):
	print("Python 3.1 or greater is required")
	sys.exit(1)

import os
import tempfile
import urllib.request
import subprocess
import shutil
import time



if len(sys.argv) != 2:
	print('Please provide address of jenkins server')
	print('Example: localhost:8090')
	sys.exit(1)

if not shutil.which('java'):
	print('Cannot find java')
	sys.exit(1)


filename = "jenkins-cli.jar"
jenkinsJar = tempfile.gettempdir() + '/' + filename

if not os.path.isfile(jenkinsJar):
	try:
		url = 'http://' + sys.argv[1] + '/jnlpJars/' + filename
		print('Download ' + url)
		jenkinsJar, headers = urllib.request.urlretrieve(url, jenkinsJar)
	except Exception as e:
		print('Cannot download ' + filename + ': ' + str(e))
		sys.exit(1)
else:
	print('Use existing: ' + jenkinsJar)


def systemCall(cmd, content = None):
	print('Calling: ' + cmd)
	try:
		result = str(subprocess.check_output(cmd, stdin=content, shell=True), 'UTF8').strip()
	except subprocess.CalledProcessError as e:
		print('Got error: ' + str(e.output, 'UTF8'))
		return 'code: ' + str(e.returncode)

	print('Got: ' + result)
	return result

def callJenkins(cmd, content = None):
	return systemCall('java -jar ' + jenkinsJar + ' -noKeyAuth -s http://' + sys.argv[1] + ' ' + cmd, content)

def installPlugin(plugin):
	return callJenkins('install-plugin ' + ' '.join(plugin) + ' -restart')

initialSessionId = callJenkins('session-id')
alreadyInstalledPlugins = callJenkins('list-plugins')

plugins = []
plugins.append('android-lint')
plugins.append('build-timeout')
plugins.append('categorized-view')
plugins.append('cobertura')
plugins.append('copyartifact')
plugins.append('cppcheck')
plugins.append('depgraph-view')
plugins.append('build-name-setter')
plugins.append('description-setter')
plugins.append('envinject')
plugins.append('extra-columns')
plugins.append('google-play-android-publisher')
plugins.append('greenballs')
plugins.append('heavy-job')
plugins.append('htmlpublisher')
plugins.append('jenkins-multijob-plugin')
plugins.append('jenkins-reviewbot')
plugins.append('jobConfigHistory')
plugins.append('job-dsl')
plugins.append('mercurial')
plugins.append('msbuild')
plugins.append('naginator')
plugins.append('nodelabelparameter')
plugins.append('parameterized-trigger')
plugins.append('show-build-parameters')
plugins.append('sloccount')
plugins.append('sidebar-link')
plugins.append('swarm')
plugins.append('tasks')
plugins.append('text-finder')
plugins.append('timestamper')
plugins.append('valgrind')
plugins.append('warnings')
plugins.append('ws-cleanup')
plugins.append('xunit')

installPlugins = []

for plugin in plugins:
	if plugin not in alreadyInstalledPlugins:
		print('Try to install plugin: ' + plugin)
		installPlugins.append(plugin)


if installPlugins:
	print('Try to install plugins... show progress at http://' + sys.argv[1] + '/updateCenter/')
	if 'code: ' in installPlugin(installPlugins):
		print('Cannot install plugins!')
		print('Maybe you need to configure a proxy in your jenkins to get update server?')
		sys.exit(1)

	print('Wait until jenkins is restarted...')
	while 1:
		time.sleep(5)
		result = callJenkins('session-id')
		if result != initialSessionId and 'code: ' not in result:
			break
		print('Wait...')

	print('Jenkins restarted...')


content = open('config.xml', "r")
if not 'code: ' in callJenkins('create-job _Seeder_', content):
	callJenkins('build _Seeder_')



#!/usr/bin/env python

import hglib
from hglib.util import b

import os
import sys

patchy = None

try:
    from rbtools.commands.patch import Patch

    class PatchHelper(Patch):
        def __init__(self):
            super(PatchHelper, self).__init__()
            parser = self.create_arg_parser([])
            self.options = parser.parse_args([])
            self.root = None
            if self.options.server is None:
                self.options.server = os.environ.get('REVIEWBOARD_SERVER')

        def download(self, request_id, diff_rev=None):
            if request_id is None:
                print('ID of review request cannot be undefined')
                return None

            if self.root is None:
                if self.options.server is None:
                    print('Cannot find Review Board! Provide .reviewboardrc?')
                    return None
                _, self.root = self.get_api(self.options.server)

            print('Download patch revision {} '
                  'of review request {}'.format(diff_rev, request_id))
            diff, _, _ = self.get_patch(request_id, self.root, diff_rev)
            return diff

        def save(self, file, request_id=None, diff_rev=None):
            if request_id is None:
                request_id = os.environ.get('REVIEWBOARD_REVIEW_ID')

            if diff_rev is None:
                diff_rev = os.environ.get('REVIEWBOARD_DIFF_REVISION')

            diff = self.download(request_id, diff_rev)

            if diff is not None:
                with open(file, 'wb') as f:
                    f.write(diff)
                    f.flush()

    patchy = PatchHelper()
except Exception:
    print('Cannot import rbtools')


def main():
    if 'BUILD_URL' not in os.environ:
        print('Warning: This script should be called on jenkins only')
        return -1

    if len(sys.argv) > 2:
        print('Unknown parameter: {}'.format(sys.argv))
        return -1

    patch = b(sys.argv[1]) if len(sys.argv) == 2 else b('../patch.diff')
    if not os.path.isfile(patch):
        if patchy is not None:
            print('Try to ask Review Board for patch file')
            patchy.save(patch)

        if not os.path.isfile(patch):
            print('Patch file "{}" does not exists'.format(patch))
            return -1

    cfg = ['extensions.hgext.purge=',
           'extensions.hgext.strip=',
           'phases.new-commit=draft']
    client = hglib.open(configs=cfg)

    print('Revert workspace...')
    client.revert(b('.'), all=True, nobackup=True)

    print('Purge workspace...')
    client.rawcommand([b('purge'), b('--all')])

    revs = len(client.log(revrange='secret() or draft()'))
    print('Found secret/draft changesets: {}'.format(revs))

    if revs > 0:
        print('Strip secret and draft changesets...')
        client.rawcommand([b('strip'),
                           b('-r'),
                           b('secret() or draft()'),
                           b('--no-backup'),
                           b('--force')])

    print('Import patch: {}'.format(patch))
    client.import_([patch],
                   user='jenkins@review',
                   date='today',
                   message='jenkins patch review')

    return 0


if __name__ == '__main__':
    sys.exit(main())
